@@ -3,9 +3,8 @@
     Copyright (C) 1997,1998  Matt Kimball
 
     This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    it under the terms of the GNU General Public License version 2 as 
+    published by the Free Software Foundation.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,6 +31,9 @@
 #include <netinet/in.h>
 #include <memory.h>
 #include <unistd.h>
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -478,6 +480,9 @@ void net_process_ping(int seq, void * addr, struct timeval now)
     if( addrcmp( (void *) &(host[index].addrs[i]), addrcopy, af ) != 0 && 
         i<MAXPATH ) {
       addrcpy( (void *) &(host[index].addrs[i]), addrcopy, af );
+      
+      /* rafaelmartins: multi path support to '--raw' */
+      display_rawhost(index, (void *) &(host[index].addrs[i]));
     }
   /* end multi paths */
   }
@@ -896,6 +901,23 @@ int net_send_batch(void)
 }
 
 
+static void set_fd_flags(int fd)
+{
+#if defined(HAVE_FCNTL) && defined(FD_CLOEXEC)
+  int oldflags;
+
+  if (fd < 0) return; 
+
+  oldflags = fcntl(fd, F_GETFD);
+  if (oldflags == -1) {
+    perror("Couldn't get fd's flags");
+    return;
+  }
+  if (fcntl(fd, F_SETFD, oldflags | FD_CLOEXEC))
+    perror("Couldn't set fd's flags");
+#endif
+}
+
 int net_preopen(void) 
 {
   int trueopt = 1;
@@ -925,8 +947,11 @@ int net_preopen(void)
   recvsock4 = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP);
   if (recvsock4 < 0)
     return -1;
+  set_fd_flags(recvsock4);
 #ifdef ENABLE_IPV6
   recvsock6 = socket(AF_INET6, SOCK_RAW, IPPROTO_ICMPV6);
+  if (recvsock6 >= 0)
+     set_fd_flags(recvsock6);
 #endif
 
   return 0;
@@ -956,7 +981,7 @@ int net_selectsocket(void)
     sendsock6 = sendsock6_udp;
     break;
   }
-  if (sendsock6 < 0)
+  if ((sendsock6 < 0) && (sendsock4 < 0))
     return -1;
 #endif
 
